@@ -4,5 +4,5 @@ Copyright (c) 2003-2005  Gustavo Niemeyer <gustavo@niemeyer.net>
 This module offers extensions to the standard python 2.3+
 datetime module.
 """
-__author__ = "Gustavo Niemeyer <niemeyer@conectiva.com>"
+__author__ = "Gustavo Niemeyer <gustavo@niemeyer.net>"
 __license__ = "PSF License"
